/**
 * {@link Mp4MediaStream.play} に指定可能なオプション
 */
interface PlayOptions {
    /**
     * true が指定されると、MP4 ファイルの終端に達した場合に、先頭に戻って再生が繰り返されます
     *
     * デフォルト値は false
     */
    repeat?: boolean;
}
/**
 * MP4 を入力にとって、それを再生する MediaStream を生成するクラス
 */
declare class Mp4MediaStream {
    private wasm;
    private memory;
    private engine;
    private info?;
    private players;
    private nextPlayerId;
    private constructor();
    /**
     * 実行環境が必要な機能をサポートしているかどうかを判定します
     *
     * 以下のクラスが利用可能である必要があります:
     * - AudioDecoder
     * - VideoDecoder
     *
     * @returns サポートされているかどうか
     */
    static isSupported(): boolean;
    /**
     * 指定された MP4 をロードします
     *
     * @param mp4 対象の MP4 データ
     *
     * @returns ロード結果の Mp4MediaStream インスタンス
     *
     * @throws
     * 指定された MP4 が不正であったり、非対応コーデックを含んでいる場合には例外が送出されます
     */
    static load(mp4: Blob): Promise<Mp4MediaStream>;
    /**
     * ロード済み MP4 の再生するための MediaStream インスタンスを生成します
     *
     * @param options 再生オプション
     *
     * @returns MP4 再生用の MediaStream インスタンス
     *
     * 複数回呼び出された場合には、それぞれが別々の MediaStream インスタンスを返します
     *
     * [注意]
     * 返り値の MediaStream は RTCPeerConnection に渡して WebRTC のソースとすることも可能です。
     * ただし、その場合には「同時に VideoElement.srcObject に指定する」などのように別に経路でも参照される
     * ようにしないと、WebRTC の受信側で映像のフレームレートが極端に下がったり、止まったりする現象が確認されています。
     * なお、VideoElement はミュートかつ hidden visibility でも問題ありません。
     */
    play(options?: PlayOptions): Promise<MediaStream>;
    /**
     * 再生中の全ての MediaStream を停止します
     *
     * 個別の MediaStream を停止したい場合には、単にそのインスタンスを破棄するか、
     * MedisStreamTrack.stop() を呼び出してください
     */
    stop(): Promise<void>;
    private stopPlayer;
    private loadMp4;
    private consoleLog;
    private sleep;
    private createVideoDecoder;
    private createAudioDecoder;
    private closeDecoder;
    private onEos;
    private decode;
    private wasmJsonToValue;
    private wasmResultToValue;
    private valueToWasmJson;
    private toWasmBytes;
}
export { Mp4MediaStream, type PlayOptions };
